==> ejc-middlemeasurement-impl-3.0.0-20230130.110416-335-sources.jar: com/ejianc/business/middlemeasurement/service/impl/SubcontractingvolumeBpmServiceImpl.java <==
package com.ejianc.business.middlemeasurement.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.middlemeasurement.bean.SubcontractingvolumeEntity;
import com.ejianc.business.middlemeasurement.bean.SubcontractingvolumedetailEntity;
import com.ejianc.business.middlemeasurement.service.ISubcontractingvolumeService;
import com.ejianc.business.middlemeasurement.service.ISubcontractingvolumedetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.costmanage.api.CostanalysisApi;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.util.List;

@Service("subcontractingvolume")
public class SubcontractingvolumeBpmServiceImpl implements ICommonBusinessService {

	@Autowired
	private CostanalysisApi costanalysisApi;

	@Autowired
	private ISubcontractingvolumeService service;

	@Autowired
	private ISubcontractingvolumedetailService subcontractingvolumedetailService;

	/**
	 * 提交前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		SubcontractingvolumeEntity entity = service.selectById(billId);
		CommonResponse<Boolean> response = costanalysisApi.isGenerate(entity.getProjectId(),entity.getReportingTime());
		if(response != null){
			Boolean isHave = response.getData();
			if(isHave != null && isHave.booleanValue()){
				return CommonResponse.error("该单据所属项目与月份已生成月度分析报告，不可提交！");
			}
		}
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		QueryWrapper<SubcontractingvolumeEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("id",billId);
		SubcontractingvolumeEntity entity = service.getOne(queryWrapper);
		CommonResponse<Boolean> generate = costanalysisApi.isGenerate(entity.getProjectId(), entity.getReportingTime());
		if(generate.isSuccess() && generate.getData()){
			return CommonResponse.error("该单据已经生成月度分析报告，不可进行操作！");
		}
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO

		//创建条件构造器
		QueryWrapper<SubcontractingvolumedetailEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("mid", billId);
		queryWrapper.eq("dr", "0");
		List<SubcontractingvolumedetailEntity> detailEntities = subcontractingvolumedetailService.list(queryWrapper);
		if(detailEntities != null && detailEntities.size() > 0){
			for (int i = 0; i < detailEntities.size(); i++) {
				SubcontractingvolumedetailEntity detail = detailEntities.get(i);
				detail.setBillState(state);//更新子表审批状态
			}

			subcontractingvolumedetailService.saveOrUpdateBatch(detailEntities);
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//查询是否生成月度分析报告
		QueryWrapper<SubcontractingvolumeEntity> queryWrapper1 = new QueryWrapper<>();
		queryWrapper1.eq("id",billId);
		SubcontractingvolumeEntity entity1 = service.getOne(queryWrapper1);
		CommonResponse<Boolean> generate = costanalysisApi.isGenerate(entity1.getProjectId(), entity1.getReportingTime());
		if(generate.isSuccess() && generate.getData()){
			return CommonResponse.error("该单据已经生成月度分析报告，不可进行操作！");
		}


		SubcontractingvolumeEntity entity = service.selectById(billId);
		Long contractId = entity.getContractId();//合同id

		//只能弃审最新的单据
		QueryWrapper<SubcontractingvolumeEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("contract_id", contractId);
		queryWrapper.eq("dr", 0);
		queryWrapper.orderByDesc("create_time");
		queryWrapper.last("limit 1");
		List<SubcontractingvolumeEntity> pro = service.list(queryWrapper);
		if(pro != null && pro.size() > 0){
			SubcontractingvolumeEntity resEntity = pro.get(0);
			Integer billState = resEntity.getBillState();
			if(!billId.equals(resEntity.getId())){//本单据不是最新
				if(billState == 1 || billState == 3){
					return CommonResponse.error("只能弃审该合同下最后一次做的已生效单据！");
				}else {
					return CommonResponse.error("已存在一个审批中或自由态的最新单据，不允许弃审！");
				}
			}else{
				if(resEntity.getIsReference() == 1){
					return CommonResponse.error("已被分包月度报量台账引用，不允许撤回！");
				}
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> ejc-middlemeasurement-impl-3.0.0-20230830.034615-488-sources.jar: com/ejianc/business/middlemeasurement/service/impl/SubcontractingvolumeBpmServiceImpl.java <==
package com.ejianc.business.middlemeasurement.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.middlemeasurement.bean.SubcontractingvolumeEntity;
import com.ejianc.business.middlemeasurement.bean.SubcontractingvolumedetailEntity;
import com.ejianc.business.middlemeasurement.service.ISubcontractingvolumeService;
import com.ejianc.business.middlemeasurement.service.ISubcontractingvolumedetailService;
import com.ejianc.business.middlemeasurement.vo.SubcontractingvolumedetailVO;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.costmanage.api.CostanalysisApi;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.util.List;

@Service("subcontractingvolume")
public class SubcontractingvolumeBpmServiceImpl implements ICommonBusinessService {

	@Autowired
	private CostanalysisApi costanalysisApi;

	@Autowired
	private ISubcontractingvolumeService service;

	@Autowired
	private ISubcontractingvolumedetailService subcontractingvolumedetailService;

	/**
	 * 提交前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		SubcontractingvolumeEntity entity = service.selectById(billId);
		CommonResponse<Boolean> response = costanalysisApi.isGenerate(entity.getProjectId(),entity.getReportingTime());
		if(response != null){
			Boolean isHave = response.getData();
			if(isHave != null && isHave.booleanValue()){
				return CommonResponse.error("该单据所属项目与月份已生成月度分析报告，不可提交！");
			}
		}
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		QueryWrapper<SubcontractingvolumeEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("id",billId);
		SubcontractingvolumeEntity entity = service.getOne(queryWrapper);
		CommonResponse<Boolean> generate = costanalysisApi.isGenerate(entity.getProjectId(), entity.getReportingTime());
		if(generate.isSuccess() && generate.getData()){
			return CommonResponse.error("该单据已经生成月度分析报告，不可进行操作！");
		}

		List<SubcontractingvolumedetailVO> voList = service.querySettleBook(entity.getProjectId());
		if(CollectionUtils.isNotEmpty(voList)){
			return CommonResponse.error("该单据已经生成工程分包结算书，不可进行操作！");
		}
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO

		//创建条件构造器
		QueryWrapper<SubcontractingvolumedetailEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("mid", billId);
		queryWrapper.eq("dr", "0");
		List<SubcontractingvolumedetailEntity> detailEntities = subcontractingvolumedetailService.list(queryWrapper);
		if(detailEntities != null && detailEntities.size() > 0){
			for (int i = 0; i < detailEntities.size(); i++) {
				SubcontractingvolumedetailEntity detail = detailEntities.get(i);
				detail.setBillState(state);//更新子表审批状态
			}

			subcontractingvolumedetailService.saveOrUpdateBatch(detailEntities);
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//查询是否生成月度分析报告
		QueryWrapper<SubcontractingvolumeEntity> queryWrapper1 = new QueryWrapper<>();
		queryWrapper1.eq("id",billId);
		SubcontractingvolumeEntity entity1 = service.getOne(queryWrapper1);
		CommonResponse<Boolean> generate = costanalysisApi.isGenerate(entity1.getProjectId(), entity1.getReportingTime());
		if(generate.isSuccess() && generate.getData()){
			return CommonResponse.error("该单据已经生成月度分析报告，不可进行操作！");
		}


		SubcontractingvolumeEntity entity = service.selectById(billId);
		Long contractId = entity.getContractId();//合同id

		//只能弃审最新的单据
		QueryWrapper<SubcontractingvolumeEntity> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("contract_id", contractId);
		queryWrapper.eq("dr", 0);
		queryWrapper.orderByDesc("create_time");
		queryWrapper.last("limit 1");
		List<SubcontractingvolumeEntity> pro = service.list(queryWrapper);
		if(pro != null && pro.size() > 0){
			SubcontractingvolumeEntity resEntity = pro.get(0);
			Integer billState = resEntity.getBillState();
			if(!billId.equals(resEntity.getId())){//本单据不是最新
				if(billState == 1 || billState == 3){
					return CommonResponse.error("只能弃审该合同下最后一次做的已生效单据！");
				}else {
					return CommonResponse.error("已存在一个审批中或自由态的最新单据，不允许弃审！");
				}
			}else{
				if(resEntity.getIsReference() == 1){
					return CommonResponse.error("已被分包月度报量台账引用，不允许撤回！");
				}
			}
		}

		List<SubcontractingvolumedetailVO> voList = service.querySettleBook(entity.getContractId());
		if(CollectionUtils.isNotEmpty(voList)){
			return CommonResponse.error("该单据已经生成工程分包结算书，不可进行操作！");
		}

		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}
